@@ -2,7 +2,7 @@
 
   FITSPNG
 
-  Copyright (C) 2006-2017  Filip Hroch, Masaryk University, Brno, CZ
+  Copyright (C) 2006-2019  Filip Hroch, Masaryk University, Brno, CZ
 
   Fitspng is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,5 +19,18 @@
 
 */
 
-/* qmed.c */
-extern float qmed(int, float *, int);
+/* fitspng.c */
+int fitspng(char *, char *,int,float,float,int,
+	    float,float,float,float,float,int,float,int,float,
+	    int,int,int,int);
+
+/* cielab.c */
+void XYZ_Lab(float, float, float,float *, float *, float *);
+void Lab_XYZ(float, float, float,float *, float *, float *);
+
+/* ecdf.c */
+int ecdf(long, const float *, float *, float *);
+float quantile(long, const float *, const float *, float);
+
+/* tone.c */
+int tone(long, const float *, float, float,float *, float *,int);
