@@ -1,7 +1,7 @@
 /*
 
   FITSPNG     FITS to PNG converter
-  Copyright (C) 2006-2017  Filip Hroch, Masaryk University, Brno, CZ
+  Copyright (C) 2006-2019  Filip Hroch, Masaryk University, Brno, CZ
 
   Fitspng is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 */
 
+#include "fitspng.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -26,32 +27,38 @@
 
 #include <assert.h>
 
+#if defined _WIN32 || defined __CYGWIN__
+#define DIRSEP '\\'
+#else
+#define DIRSEP '/'
+#endif
+
 void help();
 void version();
-int fitspng(char *, char *,int,float,float,int,float,float,float,
-	    float,float,int,float,float,float,int,float,int,int,int);
+char *pngsuff(const char *);
 
 int main(int argc,char *argv[])
 {
-  char *fits = NULL, *png = "fitspng.png";
+  char *png = NULL;
   int bit_depth, scale, type, verb;
-  float u,v,t,s,f,z,st,ss, satur = 1.0;
-  int i, set_fl, set_fn, dcspace = 0;
-  float xw = 0.2009;  /* for D65 and 2 deg. observer */
-  float yw = 0.4610;
+  float qblack,rsense,t,s,f0,fz,st,ss, satur;
+  int i, set_fl, set_fn, set_satur, dcspace = 0;
+  int nfits = 0;
+  int status = 0;
 
   bit_depth = 8;
   scale = 1;
   type = 0;
   verb = 0;
-  set_fl = 0; set_fn = 0;
+  set_fl = 0; set_fn = 0; set_satur = 0;
 
-  u = 0.5;
-  v = 15.0;
+  qblack = 0.25;
+  rsense = 1.0;
   t = 0.0;
   s = 1.0;
-  f = 1.0;
-  z = 0.0;
+  f0 = 1.0;
+  fz = 0.0;
+  satur = 1.0;
 
   if( argc == 1 ) {
     help();
@@ -98,22 +105,6 @@ int main(int argc,char *argv[])
       if( strcmp(argv[i],"linear") == 0 )
 	type = 0;
 
-      /* asinh */
-      else if( strcmp(argv[i],"asinh") == 0 )
-	type = 1;
-
-      /* magnitude */
-      else if( strcmp(argv[i],"log") == 0 )
-	type = 2;
-
-      /* gamma */
-      else if( strcmp(argv[i],"gamma") == 0 )
-	type = 3;
-
-      /* error function */
-      else if( strcmp(argv[i],"normal") == 0 )
-	type = 4;
-
       /* square root */
       else if( strcmp(argv[i],"sqrt") == 0 )
 	type = 5;
@@ -126,14 +117,6 @@ int main(int argc,char *argv[])
       else if( strcmp(argv[i],"logistic") == 0 )
 	type = 7;
 
-      /* atan */
-      else if( strcmp(argv[i],"atan") == 0 )
-	type = 8;
-
-      /* ratio */
-      else if( strcmp(argv[i],"ratio") == 0 )
-	type = 9;
-
       else {
         fprintf(stderr,"A wrong type of conversion specified.\n");
         return(1);
@@ -142,7 +125,7 @@ int main(int argc,char *argv[])
 
     /* intensity scale */
     else if( strcmp(argv[i],"-f0") == 0 && i++ < argc ){
-      if( sscanf(argv[i],"%f",&f) != 1 && f > 0.0 ) {
+      if( sscanf(argv[i],"%f",&f0) != 1 && f0 > 0.0 ) {
         fprintf(stderr,"-f0: Specify a positive real number.\n");
         return(1);
       }
@@ -150,7 +133,7 @@ int main(int argc,char *argv[])
 
     /* zero point */
     else if( strcmp(argv[i],"-fz") == 0 && i++ < argc ){
-      if( sscanf(argv[i],"%f",&z) != 1 ) {
+      if( sscanf(argv[i],"%f",&fz) != 1 ) {
         fprintf(stderr,"-fz: Specify a real number.\n");
         return(1);
       }
@@ -167,8 +150,8 @@ int main(int argc,char *argv[])
 
     /* relative intensity scale */
     else if( strcmp(argv[i],"-fr") == 0 && i++ < argc ){
-      if( sscanf(argv[i],"%f,%f",&u,&v) != 2 && v > 0.0 ) {
-        fprintf(stderr,"-fr: Specify a pair of real numbers separated by comma (second positive).\n");
+      if( sscanf(argv[i],"%f,%f",&qblack,&rsense) != 2 && rsense > 0.0 ) {
+        fprintf(stderr,"-fr: Specify a pair of real numbers separated by comma (firs should be 0 .. 1, second positive).\n");
         return(1);
       }
     }
@@ -179,14 +162,7 @@ int main(int argc,char *argv[])
         fprintf(stderr,"-fs: Specify a positive (or zero) real number.\n");
         return(1);
       }
-    }
-
-    /* white point */
-    else if( strcmp(argv[i],"-fw") == 0 && i++ < argc ){
-      if( sscanf(argv[i],"%f,%f",&xw,&yw) != 2 ) {
-        fprintf(stderr,"-fw: Specify a pair of real numbers separated by comma (both positive).\n");
-        return(1);
-      }
+      set_satur = 1;
     }
 
     /* display colourspace */
@@ -228,42 +204,62 @@ int main(int argc,char *argv[])
       if( *argv[i] == '-' )
 	fprintf(stderr,"Warning: an unknown parameter? (%s).\n",argv[i]);
 
-      fits = argv[i];
+      /* keep the index of the first FITS file on command line  */
+      if( nfits == 0 )
+	nfits = i;
     }
 
   }
 
-  if( verb )
-    fprintf(stderr,"Scaling parameters (type=%d): %f %f\n",type,u,v);
-
-  if( ! fits ) {
-    fprintf(stderr,"A FITS file is not specified.\n");
-    return(1);
+  if( nfits == 0 ) {
+    fprintf(stderr,"Error: unspecified FITS file(s).\n");
+    return 1;
   }
 
-  return(fitspng(fits,png,bit_depth,u,v,scale,f,t,s,st,ss,type,satur,xw,yw,
-		 dcspace,z,verb,!set_fl,set_fn));
+  if( argc - nfits > 1 && png ) {
+    fprintf(stderr,"Error: Set of output filename (by -o) is uncompatible"
+	  " with list of FITSes.\n");
+    return 1;
+  }
+
+  if( verb ) {
+    fprintf(stderr,"Scaling: qblack=%f rsense=%f\n",qblack,rsense);
+    fprintf(stderr,"Itt: (type=%d): f0=%f fz=%f\n",type,f0,fz);
+  }
+
+  status = 0;
+  for( i = nfits; i < argc; i++ ) {
+    char *pngname = png ? strdup(png) : pngsuff(argv[i]);
+    int code = fitspng(argv[i],pngname,bit_depth,qblack,rsense,scale,f0,t,s,st,
+		       ss,type,satur,dcspace,fz,verb,!set_fl,set_fn,set_satur);
+    if( code != 0 ) {
+      status = 2;
+      fprintf(stderr,"Error: fitspng failed for `%s'.\n",argv[i]);
+    }
+
+    free(pngname);
+  }
+
+  return status;
 }
 
 
 void help()
 {
-  printf("%s\n\n%s\n\n%s\n%s\n%s\n%s\n %s\n%s\n%s\n %s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n",
+  printf("%s\n\n%s\n\n%s\n%s\n%s\n%s\n %s\n%s\n %s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n%s\n",
 	 "FITSPNG    FITS to PNG converter",
-	 "Usage: fitspng [options] file",
+	 "Usage: fitspng [options] file(s)",
 	 "options:",
-	 "\t-f x\t tone function - Func(..): linear (default), asinh, log,",
-	 "\t\t gamma, normal, sqrt, sqr (square), logistic, atan, ratio",
-	 "\t-f0 f\t parameter: f0*Func(..) (default: 1)",
-	 "\t-fz z\t zero parameter: Func(..) + z (default: 0)",
-	 "\t-fr u,v\t scale parameters: (median-u*mad)/(mad/v) (default: 3,1/3)",
-	 "\t-fl t,s\t scale parameters: (x-t)/s",
+	 "\t-f x\t Itt tone function: linear, sqrt, sqr, logistic",
+	 "\t-f0 f\t f0 parameter: f0*f(t)+z0 (default: 1)",
+	 "\t-fz z\t zero z0 parameter: f0*f(t)+z0 (default: 0)",
+	 "\t-fr q,v\t relative scaling parameters: 0<=q<=1, v>0",
+	 "\t-fl B,s\t scale parameters: (x-B)/s",
 	 "\t-fs x\t colour saturation (default: 1)",
-	 "\t-fn st,ss threshold and width for night/day vision (no default)",
-	 "\t-fw x,y\t coordinates of white point",
+	 "\t-fn tn,sn threshold and width for night/day vision (no default)",
 	 "\t-cs x\t output colour-space: sRGB (default) or AdobeRGB",
 	 "\t-s s\t zoom-out image by 1/s, to create thumbnails (default: 1)",
-	 "\t-o\t output filename (default: fitspng.png)",
+	 "\t-o\t output filename (considered for single file input)",
 	 "\t-B\t bits per pixel of output image: 8,16 (default: 8)",
 	 "\t-v\t verbose mode",
 	 "\t--help\t\t give this help",
@@ -273,10 +269,35 @@ void help()
 
 void version()
 {
-  fprintf(stdout,"FITSPNG, %s, (C) 2006-2017 F. Hroch,"
+  fprintf(stdout,"FITSPNG, %s, (C) 2006-2019 F. Hroch,"
 	  " Masaryk University in Brno, CZ\n",VERSION);
   fprintf(stdout,"FITSPNG comes with ABSOLUTELY NO WARRANTY.\n");
   fprintf(stdout,"You may redistribute copies of FITSPNG\n");
   fprintf(stdout,"under the terms of the GNU General Public License.\n");
   fprintf(stdout,"For more information about these matters, see the file named COPYING.\n");
 }
+
+char *pngsuff(const char *fitspath)
+{
+  char *png = 0;
+  const char *fits = 0, *dot = 0;
+
+  /* extracting basename */
+  if( (fits = strrchr(fitspath,DIRSEP)) == NULL )
+    fits = fitspath;
+  else
+    fits++;
+
+  /* suffix like ".fits" is replaced by ".png" */
+  if( (png = malloc(strlen(fits) + 5)) == NULL )
+    perror(__FILE__);
+  *png = '\0'; /* should be initialised with null-terminating byte */
+  assert(png && fits);
+  if( (dot = strchr(fits,'.')) != NULL )
+    strncat(png,fits,dot-fits);
+  else
+    strcat(png,fits);
+  strcat(png,".png");
+
+  return png;
+}
